pub struct SecureTextEdit<'a> { /* private fields */ }Expand description
A widget for editing text that is secured by a SecureString.
This widget is identical to egui::TextEdit, but it uses a SecureString instead of a std::string::String.
Notes
- Accessability like screen readers is disabled to avoid multiple unsecure allocations of the entered text.
- If you want to make sure the text you enter doesn’t stay in memory in any way you have to set
Self::passwordtotrue.
Otherwise egui will make copies of that text and some of the copied allocations will stay in memory.