pub struct Button<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Button<'a>
impl<'a> Button<'a>
pub fn new(atoms: impl IntoAtoms<'a>) -> Self
Sourcepub fn selectable(selected: bool, atoms: impl IntoAtoms<'a>) -> Self
pub fn selectable(selected: bool, atoms: impl IntoAtoms<'a>) -> Self
Show a selectable button.
Equivalent to:
let selected = true;
ui.add(Button::new("toggle me").selected(selected).frame_when_inactive(!selected).frame(true));See also:
Sourcepub fn image(image: impl Into<Image<'a>>) -> Self
pub fn image(image: impl Into<Image<'a>>) -> Self
Creates a button with an image. The size of the image as displayed is defined by the provided size.
Note: In contrast to Button::new, this limits the image size to the default font height
(using [crate::AtomExt::atom_max_height_font_size]).
Sourcepub fn image_and_text(
image: impl Into<Image<'a>>,
text: impl Into<WidgetText>,
) -> Self
pub fn image_and_text( image: impl Into<Image<'a>>, text: impl Into<WidgetText>, ) -> Self
Creates a button with an image to the left of the text.
Note: In contrast to Button::new, this limits the image size to the default font height
(using [crate::AtomExt::atom_max_height_font_size]).
Sourcepub fn opt_image_and_text(
image: Option<Image<'a>>,
text: Option<WidgetText>,
) -> Self
pub fn opt_image_and_text( image: Option<Image<'a>>, text: Option<WidgetText>, ) -> Self
Create a button with an optional image and optional text.
Note: In contrast to Button::new, this limits the image size to the default font height
(using [crate::AtomExt::atom_max_height_font_size]).
Sourcepub fn wrap_mode(self, wrap_mode: TextWrapMode) -> Self
pub fn wrap_mode(self, wrap_mode: TextWrapMode) -> Self
Set the wrap mode for the text.
By default, [crate::Ui::wrap_mode] will be used, which can be overridden with [crate::Style::wrap_mode].
Note that any \n in the text will always produce a new line.
Sourcepub fn wrap(self) -> Self
pub fn wrap(self) -> Self
Set Self::wrap_mode to TextWrapMode::Wrap.
Sourcepub fn frame_when_inactive(self, frame_when_inactive: bool) -> Self
pub fn frame_when_inactive(self, frame_when_inactive: bool) -> Self
If false, the button will not have a frame when inactive.
Default: true.
Note: When [Self::frame] (or ui.visuals().button_frame) is false, this setting
has no effect.
Sourcepub fn sense(self, sense: Sense) -> Self
pub fn sense(self, sense: Sense) -> Self
By default, buttons senses clicks.
Change this to a drag-button with Sense::drag().
Sourcepub fn image_tint_follows_text_color(
self,
image_tint_follows_text_color: bool,
) -> Self
pub fn image_tint_follows_text_color( self, image_tint_follows_text_color: bool, ) -> Self
If true, the tint of the image is multiplied by the widget text color.
This makes sense for images that are white, that should have the same color as the text color. This will also make the icon color depend on hover state.
Default: false.
Sourcepub fn shortcut_text(self, shortcut_text: impl Into<Atom<'a>>) -> Self
pub fn shortcut_text(self, shortcut_text: impl Into<Atom<'a>>) -> Self
Show some text on the right side of the button, in weak color.
Designed for menu buttons, for setting a keyboard shortcut text (e.g. Ctrl+S).
The text can be created with [crate::Context::format_shortcut].
See also Self::right_text.
Sourcepub fn right_text(self, right_text: impl Into<Atom<'a>>) -> Self
pub fn right_text(self, right_text: impl Into<Atom<'a>>) -> Self
Show some text on the right side of the button.
Sourcepub fn visuals(self, visuals: ButtonVisuals) -> Self
pub fn visuals(self, visuals: ButtonVisuals) -> Self
Set the visuals of the button
Sourcepub fn atom_ui(self, ui: &mut Ui) -> AtomLayoutResponse
pub fn atom_ui(self, ui: &mut Ui) -> AtomLayoutResponse
Show the button and return a AtomLayoutResponse for painting custom contents.